
#ifndef KPIMUTILS_EXPORT_H
#define KPIMUTILS_EXPORT_H

#ifdef KPIMUTILS_STATIC_DEFINE
#  define KPIMUTILS_EXPORT
#  define KPIMUTILS_NO_EXPORT
#else
#  ifndef KPIMUTILS_EXPORT
#    ifdef kpimutils_EXPORTS
        /* We are building this library */
#      define KPIMUTILS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KPIMUTILS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KPIMUTILS_NO_EXPORT
#    define KPIMUTILS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KPIMUTILS_DEPRECATED
#  define KPIMUTILS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KPIMUTILS_DEPRECATED_EXPORT
#  define KPIMUTILS_DEPRECATED_EXPORT KPIMUTILS_EXPORT KPIMUTILS_DEPRECATED
#endif

#ifndef KPIMUTILS_DEPRECATED_NO_EXPORT
#  define KPIMUTILS_DEPRECATED_NO_EXPORT KPIMUTILS_NO_EXPORT KPIMUTILS_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KPIMUTILS_NO_DEPRECATED
#    define KPIMUTILS_NO_DEPRECATED
#  endif
#endif

#endif /* KPIMUTILS_EXPORT_H */
